dispMUA.arDispMUAAllocation["<"] =
{
  "<winnt's callegra" : [ "callegra.png" , "http://www.callware.com/unified.html" ] ,
  "<jtl-wawi mail>" : [ "jtl-software.png" , "http://www.jtl-software.de/" ] ,
  "<winnt's blat" : [ "blat.png" , "http://www.blat.net/" ] ,
  "<!-- coremail" : [ "coremail.png" , "http://www.mailtech.cn/" ] ,
  "< iwin.com" : [ "iwin_com.png" , "http://www.iwin.com/" ] ,
  "<asp.net" : [ "asp_net.png" , "http://www.asp.net/" ] ,
  "<smtp32" : [ "imail.png" , "http://www.imailserver.com/" ] ,
  "<imail" : [ "imail.png" , "http://www.imailserver.com/" ] ,
}
